export default getLogger;
export type LogLevel = 'trace' | 'debug' | 'info' | 'warn' | 'error' | 'fatal';
export type LoggerOptions = {
    writeToConsole?: boolean;
    writeAsObject?: boolean;
    level?: LogLevel;
    beaconLevel?: LogLevel;
    sendLogs?: boolean;
};
export type LogFn = (data: any, message: any) => void;
export type LoggerInstance = {
    trace: LogFn;
    debug: LogFn;
    info: LogFn;
    warn: LogFn;
    error: LogFn;
    fatal: LogFn;
    child: (any: any) => LoggerInstance;
};
/** @typedef {'trace' | 'debug' | 'info' | 'warn' | 'error' | 'fatal'} LogLevel */
/**
 * @typedef {{
 *   writeToConsole?: boolean
 *   writeAsObject?: boolean
 *   level?: LogLevel
 *   beaconLevel?: LogLevel
 *   sendLogs?: boolean
 * }} LoggerOptions
 */
/** @typedef {(data, message) => void} LogFn */
/**
 * @typedef {{
 *   trace: LogFn
 *   debug: LogFn
 *   info: LogFn
 *   warn: LogFn
 *   error: LogFn
 *   fatal: LogFn
 *   child: (any) => LoggerInstance
 * }} LoggerInstance
 */
/**
 * @param {LoggerOptions} spec
 * @param {any} bindings
 * @returns {LoggerInstance}
 */
declare function getLogger(spec: LoggerOptions, bindings: any): LoggerInstance;
